/* ISC license. */

#include <skalibs/tai.h>

tain const tain_zero = TAIN_ZERO ;
